==> huaweicloudsdkmetastudio-3.1.142-py2.py3-none-any.whl: huaweicloudsdkmetastudio/v1/model/show_training_segment_info_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowTrainingSegmentInfoResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'confirmed_index': 'list[int]'
    }

    attribute_map = {
        'confirmed_index': 'confirmed_index'
    }

    def __init__(self, confirmed_index=None):
        """ShowTrainingSegmentInfoResponse

        The model defined in huaweicloud sdk

        :param confirmed_index: 确认过的语句索引。
        :type confirmed_index: list[int]
        """
        
        super(ShowTrainingSegmentInfoResponse, self).__init__()

        self._confirmed_index = None
        self.discriminator = None

        if confirmed_index is not None:
            self.confirmed_index = confirmed_index

    @property
    def confirmed_index(self):
        """Gets the confirmed_index of this ShowTrainingSegmentInfoResponse.

        确认过的语句索引。

        :return: The confirmed_index of this ShowTrainingSegmentInfoResponse.
        :rtype: list[int]
        """
        return self._confirmed_index

    @confirmed_index.setter
    def confirmed_index(self, confirmed_index):
        """Sets the confirmed_index of this ShowTrainingSegmentInfoResponse.

        确认过的语句索引。

        :param confirmed_index: The confirmed_index of this ShowTrainingSegmentInfoResponse.
        :type confirmed_index: list[int]
        """
        self._confirmed_index = confirmed_index

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowTrainingSegmentInfoResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmetastudio-3.1.153-py2.py3-none-any.whl: huaweicloudsdkmetastudio/v1/model/show_training_segment_info_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowTrainingSegmentInfoResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'confirmed_index': 'list[int]'
    }

    attribute_map = {
        'confirmed_index': 'confirmed_index'
    }

    def __init__(self, confirmed_index=None):
        r"""ShowTrainingSegmentInfoResponse

        The model defined in huaweicloud sdk

        :param confirmed_index: 确认过的语句索引。
        :type confirmed_index: list[int]
        """
        
        super(ShowTrainingSegmentInfoResponse, self).__init__()

        self._confirmed_index = None
        self.discriminator = None

        if confirmed_index is not None:
            self.confirmed_index = confirmed_index

    @property
    def confirmed_index(self):
        r"""Gets the confirmed_index of this ShowTrainingSegmentInfoResponse.

        确认过的语句索引。

        :return: The confirmed_index of this ShowTrainingSegmentInfoResponse.
        :rtype: list[int]
        """
        return self._confirmed_index

    @confirmed_index.setter
    def confirmed_index(self, confirmed_index):
        r"""Sets the confirmed_index of this ShowTrainingSegmentInfoResponse.

        确认过的语句索引。

        :param confirmed_index: The confirmed_index of this ShowTrainingSegmentInfoResponse.
        :type confirmed_index: list[int]
        """
        self._confirmed_index = confirmed_index

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowTrainingSegmentInfoResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
